# Simulations of YM with LatticeGPU.jl

This is a main program to simulate YM `SU(2)` and `SU(3)`
theories. The main porpose is to compare with the existing literature
and validate the code.

[[_TOC_]]

## Installation, analysis and storing results

### Installation

1. clone the repo: `git clone https://gitlab.ift.uam-csic.es/alberto/test_latticegpu.jl.git`
2. Start julia and `instantiate` the project:
```julia
julia> import Pkg
julia> Pkg.instantiate("/path/to/test_latticegpu.jl")
julia> using CUDA
julia> A = randn(1000)
julia> Ac = CuArray(1000)
```
	this should install all dependencies and dowload the necessary
	`CUDA` packages. The `Manifest.toml` file guarantees that all runs
	are performed with the same versions of all packages,
	independently on the system where this runs.

### Running simulations 

1. To run a simulation use:
```bash
[user@cluster]$ julia --project=/path/to/test_latticegpu.jl /path/to/test_latticegpu.jl/main/ym.jl -i <input file>
```
2. An example input file is available in `examples/ym.in`

### Analysis

The `BDIO` file of the simulation can be analized with the
[ana.jl](./main/ana.jl) program. An example execution is:
```bash
[user@cluster]$ julia --project=/path/to/test_latticegpu.jl /path/to/test_latticegpu.jl/main/ana.jl -i <bdio file> -o <dir> [-c <target t^2<E(t)>>]
```
The directory `<dir>` should exist before running the program. 

This program only performs some basic analysis, and should be cross-checked.

### Storing results of the simulations

Data from testing runs should be collected in the `data` folder. The
input file should be included in this git repository. The `log.gz` and
`bdio` files should be stored in ciclope (path:
`/net/ciclope-backend/mnt/IFTLattice/ALPHA/test_LatticeGPU`) using
`dvc`. 

To get a list of all simulation results stored in ciclope, run:
```bash
[user@cluster]$ dvc list -R --dvc-only https://gitlab.ift.uam-csic.es/alberto/test_latticegpu.jl.git
```

## TODO list

### Screwing with `LatticeGPU`

This section is devoted to repeating small runs with different
parameters (i.e. `block sizes`, strange `geometries` to make sure that
everything works as expected).

### Reproducing numbers in the literature

#### Flow measurements in arXiv:1006.4518

- `SU(3)` at $`\beta = 5.96`$ with lattice size $`24^3 \times 48`$,
  periodic boundary conditions:
  - [input file](./data/SU3_PBC_bt5.96_L24x24x24x48/SU3_PBC_bt5.96_L24x24x24x48.in)
  - [analysis](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis)
  - [results](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis/results.txt)
- Numerical results for t0/a^2 are barely compatible:
  - $`\langle t0\rangle = 2.7854(62)`$ (arXiv:1006.4518, table 1).
  - $`\langle t0\rangle = 2.7719(43)`$ 
	[results](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis/results.txt)
- The history of the topological charge does not look good.

#### Flow measurements in arXiv:1710.07526 and arXiv:1805.07106

- These are simulations in `SU(2)` at $`\beta = 2.5`$ with lattice
  size $`24^3 \times 48`$. 
  - [input file](./data/SU3_PBC_bt5.96_L24x24x24x48/SU3_PBC_bt5.96_L24x24x24x48.in)
  - [analysis](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis)
  - [results](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis/results.txt)
- The plaquette agrees perfectly (assuming that the reference missed a
  factor two in the definition of the plaquette):
  - $`\langle P\rangle = 0.651967(2)`$ (arXiv:1710.07526, table VII).
  - $`\langle P\rangle = 0.6519656(57)`$
    ([results](./data/SU3_PBC_bt5.96_L24x24x24x48/analysis/results.txt))
	
	
